.preview {
}

.previews .preview {
    float:left;
    margin:2em;
    color:#000000;
    position:relative;
    padding-right:20px;
}

/* clearfix */
.previews:after {
    content: ".";
    display: block;
    height: 0;
    clear: both;
    visibility: hidden;
}

.preview .deletelink-media {
    position:absolute;
    top:5px;
    right:5px;
    background:transparent url(../img/delete.gif) no-repeat scroll 0 0;
    width:10px;
    height:10px;
}
