<a id="media-{{ object.pk }}" href="{{ object.file.url }}" style="display:block;width:{{ width }}px;height:{{ height }}px;">{{ object }}</a>
<script type="text/javascript">flowplayer("media-{{ object.pk }}", "{% firstof STATIC_URL MEDIA_URL %}mediastore/flowplayer/flowplayer-3.1.4.swf", { clip: { autoPlay: true } });</script>
