{% load i18n %}
<script type="text/javascript">
    swfobject.registerObject("media-{{ object.pk }}", "9.0.0", "{% firstof STATIC_URL MEDIA_URL %}mediastore/swfobject/expressInstall.swf");
</script>
<object id="media-{{ object.pk }}" classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" width="300" height="120">
    <param name="movie" value="{{ object.file.url }}" />
    <!--[if !IE]>--><object type="application/x-shockwave-flash" data="{{ object.file.url }}" width="300" height="120"><!--<![endif]-->
        <p>{% trans "To view this content you need to install the latest flash player. Please click on the following button to download the latest flash player for your browser." %}</p>
        <p><a href="http://www.adobe.com/go/getflashplayer"><img src="http://www.adobe.com/images/shared/download_buttons/get_flash_player.gif" alt="Get Adobe Flash player" /></a></p>
    <!--[if !IE]>--></object><!--<![endif]-->
</object>
