<div class="module mediatype">
    {% if icon_url %}
    <div class="icon">
        <label{{ label_for|safe }}>
        <img src="{{ icon_url }}" alt="" />
        </label>
    </div>
    {% endif %}
    <div class="label">
        {{ input }}
        {{ label }}
    </div>
    {% if help_text %}
    <p class="help">{{ help_text }}</p>
    {% endif %}
</div>
